.. _spkg_symmetrica:

symmetrica: Library for representation theory
=======================================================

Description
-----------

Symmetrica is a Collection of C routines for representation theory.

It is a program developed by Lehrstuhl Mathematik II of the
University of Bayreuth. It has routines to handle the following topics:

-  ordinary representation theory of the symmetric group and related
   groups (2/11/04)
-  ordinary representation theory of the classical groups
-  modular representation theory of the symmetric group
-  projective representation theory of the symmetric group
-  combinatorics of tableaux
-  symmetric functions and polynomials (7/22/04)
-  commutative and non commutative Schubert polynomials
-  operations of finite groups.
-  ordinary representation theory of Hecke algebras of type A_n

For more details check http://www.algorithm.uni-bayreuth.de/en/research/SYMMETRICA

Updated package on https://gitlab.com/sagemath/symmetrica/-/releases
with changes to modernize the source and the build system.

License
-------

Public Domain (see the above web site)


Upstream Contact
----------------

-  (passed away in 2013) Axel Kohnert - see http://www.mathe2.uni-bayreuth.de/axel/

Type
----

standard


Dependencies
------------

- :ref:`spkg_xz`

Version Information
-------------------

package-version.txt::

    3.1.0


Equivalent System Packages
--------------------------

.. tab:: Arch Linux

   .. CODE-BLOCK:: bash

       $ sudo pacman -S symmetrica 


.. tab:: conda-forge

   .. CODE-BLOCK:: bash

       $ conda install symmetrica 


.. tab:: Debian/Ubuntu

   .. CODE-BLOCK:: bash

       $ sudo apt-get install libsymmetrica2-dev 


.. tab:: Fedora/Redhat/CentOS

   .. CODE-BLOCK:: bash

       $ sudo dnf install symmetrica-devel 


.. tab:: FreeBSD

   .. CODE-BLOCK:: bash

       $ sudo pkg install math/symmetrica 


.. tab:: Gentoo Linux

   .. CODE-BLOCK:: bash

       $ sudo emerge sci-libs/symmetrica 


.. tab:: Nixpkgs

   .. CODE-BLOCK:: bash

       $ nix-env -f \'\<nixpkgs\>\' --install --attr symmetrica 


.. tab:: Void Linux

   .. CODE-BLOCK:: bash

       $ sudo xbps-install symmetrica-devel 



See https://repology.org/project/symmetrica/versions

If the system package is installed, ``./configure`` will check if it can be used.

